==> openjdk-21_21.0.3+9.orig.tar.xz: openjdk-21-21.0.3+9/src/hotspot/os_cpu/windows_aarch64/pauth_windows_aarch64.inline.hpp <==
/*
 * Copyright (c) 2021, 2022, Arm Limited. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

#ifndef OS_CPU_WINDOWS_AARCH64_PAUTH_WINDOWS_AARCH64_INLINE_HPP
#define OS_CPU_WINDOWS_AARCH64_PAUTH_WINDOWS_AARCH64_INLINE_HPP

// OS specific Support for ROP Protection in VM code.
// For more details on PAC see pauth_aarch64.hpp.

inline address pauth_strip_pointer(address ptr) {
  // No PAC support in windows as of yet.
  return ptr;
}

inline address pauth_sign_return_address(address ret_addr, address sp) {
  // No PAC support in windows as of yet.
  return ret_addr;
}

inline address pauth_authenticate_return_address(address ret_addr, address sp) {
  // No PAC support in windows as of yet.
  return ret_addr;
}

#endif // OS_CPU_WINDOWS_AARCH64_PAUTH_WINDOWS_AARCH64_INLINE_HPP

==> openjdk-21_21.0.8+9.orig.tar.xz: openjdk-21-21.0.8+9/src/hotspot/os_cpu/windows_aarch64/pauth_windows_aarch64.inline.hpp <==
/*
 * Copyright (c) 2021, 2023, Arm Limited. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

#ifndef OS_CPU_WINDOWS_AARCH64_PAUTH_WINDOWS_AARCH64_INLINE_HPP
#define OS_CPU_WINDOWS_AARCH64_PAUTH_WINDOWS_AARCH64_INLINE_HPP

// OS specific Support for ROP Protection in VM code.
// For more details on PAC see pauth_aarch64.hpp.

inline address pauth_strip_pointer(address ptr) {
  // No PAC support in windows as of yet.
  return ptr;
}

inline address pauth_sign_return_address(address ret_addr) {
  // No PAC support in windows as of yet.
  return ret_addr;
}

inline address pauth_authenticate_return_address(address ret_addr) {
  // No PAC support in windows as of yet.
  return ret_addr;
}

#endif // OS_CPU_WINDOWS_AARCH64_PAUTH_WINDOWS_AARCH64_INLINE_HPP
